from fastapi import APIRouter, Response, HTTPException, status

from node.swarm import NodeSwarm
from database.schemas.cam_groups import GroupFull

switch_router = APIRouter()
swarm = NodeSwarm()


@switch_router.post("/set_group_id/{group_id}", response_model=GroupFull)
async def set_group_id(
        group_id: int
):
    group = await swarm.set_group_by_id(group_id)
    return group


@switch_router.post("/set_group_slug/{group_slug}", response_model=GroupFull)
async def set_group_slug(
        group_slug: str
):
    group = await swarm.set_group_by_slug(group_slug)
    return group


@switch_router.get("/snapshot/{node_id}")
async def get_image_from_node(node_id: int):
    node = swarm.get_connection(node_id)
    if node is None:
        raise HTTPException(
            status_code=status.HTTP_404_NOT_FOUND
        )

    snapshot_data = await node.get_image()
    return Response(content=snapshot_data, media_type="image/jpeg")


@switch_router.on_event("startup")
async def startup_event():
    await swarm.connect_all()
