FROM python:3.11-slim
LABEL authors="Mikhail Sennikov"

RUN pip3 install aiohttp fastapi lxml onvif-zeep-async uvicorn

COPY ./ /ptz-proxy
WORKDIR /ptz-proxy/rtsp
RUN apt-get update && \
    apt-get install -y ca-certificates wget curl gnupg ffmpeg --no-install-recommends && \
    ./download_mediamtx.sh && \
    rm -rf /var/lib/apt/lists/*
ENV NODE_MAJOR=20
RUN mkdir -p /etc/apt/keyrings && \
    curl -fsSL https://deb.nodesource.com/gpgkey/nodesource-repo.gpg.key | \
    gpg --dearmor -o /etc/apt/keyrings/nodesource.gpg && \
    echo "deb [signed-by=/etc/apt/keyrings/nodesource.gpg] https://deb.nodesource.com/node_$NODE_MAJOR.x nodistro main" | \
    tee /etc/apt/sources.list.d/nodesource.list && \
    apt-get update && \
    apt-get install -y nodejs --no-install-recommends && \
    rm -rf /var/lib/apt/lists/*

WORKDIR /ptz-proxy/frontend
RUN npm install && npm run build && npm prune --production

WORKDIR /ptz-proxy
CMD ["python", "-m", "uvicorn", "main:app", "--reload", "--host", "0.0.0.0", "--port", "9000"]