import asyncio

from asyncio import Task
from fastapi import FastAPI

from node_settings.node_settings import node_router
from onvif_proxy.onvif_proxy import onvif_router
from rtsp.rtsp_placeholder import start_rtsp_server
from node_switch.proxy_switch import switch_router

app = FastAPI()

app.include_router(
    onvif_router,
    prefix="/onvif",
    tags=["ONVIF proxy"],
)

app.include_router(
    switch_router,
    prefix="/switch",
    tags=["Proxy switch"],
)

app.include_router(
    node_router,
    prefix="/node",
    tags=["Proxy node settings"],
)

rtsp_task = None


@app.on_event("startup")
async def startup_event():
    global rtsp_task
    rtsp_task = asyncio.create_task(start_rtsp_server())


@app.on_event("shutdown")
def shutdown_event():
    global rtsp_task
    if isinstance(rtsp_task, Task):
        rtsp_task.cancel()
