import aiohttp
from fastapi import APIRouter, Response, HTTPException, status

from .switch_utils import get_current_cam

from node_settings.node_settings import hot_cams
from database.schemas.cams import CamOut


switch_router = APIRouter()


@switch_router.get("/active_cam", response_model=CamOut)
async def get_active_cam():
    return get_current_cam()


@switch_router.post("/choose_camera/{cam_id}", response_model=CamOut)
async def choose_camera(cam_id: int):
    return await hot_cams.switch_camera(cam_id)


@switch_router.get("/snapshot")
async def get_image():
    camera = get_current_cam()

    # Getting the snapshot URI
    if camera.profiles is None or len(camera.profiles) == 0:
        raise HTTPException(
            status_code=status.HTTP_503_SERVICE_UNAVAILABLE,
            detail="Camera is not available.",
        )

    media_profile = camera.profiles[0]
    snapshot_uri = (await camera.media_service.GetSnapshotUri({'ProfileToken': media_profile.token})).Uri

    # Downloading a snapshot into memory
    async with aiohttp.ClientSession() as session:
        async with session.get(snapshot_uri, auth=aiohttp.BasicAuth(camera.username, camera.password)) as response:
            snapshot_data = await response.read()

    # Return a file response with the specified file path
    return Response(content=snapshot_data, media_type="image/jpeg")
