import asyncio
import subprocess
from asyncio import Task

import config


async def start_rtsp_server():
    ffmpeg = None
    mediamtx = None

    try:
        mediamtx = asyncio.create_task(
            start_service(
                "MediaMTX",
                [config.mediamtx_path, "rtsp/mediamtx.yml"]
            )
        )
        await asyncio.sleep(3)
        ffmpeg = asyncio.create_task(
            start_service(
                "FFmpeg",
                [
                    "ffmpeg",
                    "-loop", "1",
                    "-i", "onvif_proxy/snapshot.jpg",
                    "-r", "5",
                    "-c:v", "libx264",
                    "-preset", "ultrafast",
                    "-tune", "zerolatency",
                    "-f", "rtsp",
                    "rtsp://localhost:8554/stream"
                ]
            )
        )

        await ffmpeg
        await mediamtx

    except asyncio.CancelledError:
        if isinstance(ffmpeg, Task):
            ffmpeg.cancel()

        if isinstance(mediamtx, Task):
            mediamtx.cancel()


async def start_service(name: str, args: list):
    process = None
    while True:
        try:
            # Start the service with the specified parameters
            process = await asyncio.create_subprocess_exec(
                *args,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE
            )

            # Waiting for the service to complete
            stdout, stderr = await process.communicate()

            # If the service completed without errors, exit the loop
            if process.returncode == 0:
                break
            else:
                print(f"{name}: Exited with error: {process.returncode}")
                print(f"{name}:\n{stderr.decode()}")
                await asyncio.sleep(0.5)

        except asyncio.CancelledError:
            # If the task was cancelled, the service ends and the loop exits
            try:
                process.terminate()
            except ProcessLookupError:
                pass

            break

        except Exception as e:
            print(f"{name}: An error occurred: {e}")

    print(f"{name}: Process finished")
