# ONVIF PTZ proxy service

This is a service that allows you to quickly switch
between several ONVIF cameras for control from a single PTZ remote control.

The service is based on the fastapi framework
and the onvif-zeep-async library and is a SOAP
proxy server with the substitution of authorization data,
URL and other fields of the ONVIF protocol.

The service contains Web UI written on Vue3
and RTSP server to avoid conflicts with client programs.

## Before begin

Dependencies need to be loaded:
```sh
git submodule update --init --recursive
```

## Configuration

### __config.py__ is used for configuration.

### Server section

The server section contains external IP and ports.

This does not change the proxy settings and is used
for link spoofing, so the ports must match the external
ports of docker or nginx, if available.

Internal ports must always be 9000 for API and proxy, and 8554 for RTSP.

```python
server = {
    'host': '192.168.1.106',
    'onvif_port': 8080,
    'rtsp_port': 8554
}
```

```yaml
ports:
  - "0.0.0.0:8080:9000"
  - "0.0.0.0:8554:8554"
```

### Services to proxy

Used to replace fields in a GetCapabilities request.
Some programs (eg ODM) do not use the host from this
request and route all requests through a proxy.
Such requests will also be processed, however, correct
behavior is guaranteed only for PTZ and Media.

```python
services_to_proxy = {
    # 'Analytics',
    # 'Device',
    # 'Events',
    # 'Imaging',
    'Media',
    'PTZ',
    # 'DeviceIO',
    # 'Recording',
    # 'Search',
    # 'Replay'
}
```

### Cams section

The Cams section is temporarily used to specify a list of cameras.

```python
cams = [
    {
        'name': 'MyCamera',
        'host': '123.123.123.123',
        'port': 80,
        'username': 'admin',
        'password': 'admin'
    },
]
```

## Deploy

```sh
sudo docker-compose up -d
```

The correct startup:

```sh
[+] Running 2/2
 ✔ Container ptz-proxy-fastapi-frontend-builder-1  Exited
 ✔ Container ptz-proxy-fastapi-ptx-proxy-1         Running
```